# tket-py documentation

## API documentation
```{eval-rst}
.. autosummary::
   :toctree: generated
   :caption: API documentation
   :template: autosummary/module.rst
   :recursive:

   tket.circuit
   tket.ops
   tket.optimiser
   tket.pattern
   tket.rewrite
   tket.passes
   tket.types

.. toctree::
   :caption: Examples

   examples/Guppy-opt-example

```
